Crate tipc_std

Crate tipc_std 

TIPC standard library type provider.

Provides the same API surface as trusty_std (TryClone, FallibleCString, Mutex, etc.) in a no_std environment backed by core + alloc. Both lk and x-kernel targets are no_std; the feature only selects syscall numbering.

Modules

alloc
Allocation types for tipc-std.
any
Utilities for dynamic typing or type reflection.
arch
SIMD and vendor intrinsics module.
array
Utilities for the array primitive type.
borrow
A module for working with borrowed data.
boxed
The Box<T> type for heap allocation.
cell
Shareable mutable containers.
char
Utilities for the char primitive type.
clone
The Clone trait for types that cannot be ‘implicitly copied’.
cmp
Utilities for comparing and ordering values.
convert
Traits for conversions between types.
default
The Default trait for types with a default value.
ffi
FFI types for tipc-std.
fmt
Utilities for formatting and printing Strings.
future
Asynchronous basic functionality.
hash
Generic hashing support.
hint
Hints to compiler that affects how code should be emitted or optimized.
i8Deprecation planned
Redundant constants module for the i8 primitive type.
i16Deprecation planned
Redundant constants module for the i16 primitive type.
i32Deprecation planned
Redundant constants module for the i32 primitive type.
i64Deprecation planned
Redundant constants module for the i64 primitive type.
i128Deprecation planned
Redundant constants module for the i128 primitive type.
isizeDeprecation planned
Redundant constants module for the isize primitive type.
iter
Composable external iteration.
marker
Primitive traits and types representing basic properties of types.
mem
Basic functions for dealing with memory, values, and types.
ops
Overloadable operators.
option
Optional values.
pin
Types that pin data to a location in memory.
primitive
This module reexports the primitive types to allow usage that is not possibly shadowed by other declared types.
ptr
Manually manage memory through raw pointers.
rc
Single-threaded reference-counting pointers. ‘Rc’ stands for ‘Reference Counted’.
result
Error handling with the Result type.
slice
Utilities for the slice primitive type.
str
Utilities for the str primitive type.
string
A UTF-8–encoded, growable string.
sync
Synchronization primitives for tipc-std.
u8Deprecation planned
Redundant constants module for the u8 primitive type.
u16Deprecation planned
Redundant constants module for the u16 primitive type.
u32Deprecation planned
Redundant constants module for the u32 primitive type.
u64Deprecation planned
Redundant constants module for the u64 primitive type.
u128Deprecation planned
Redundant constants module for the u128 primitive type.
usizeDeprecation planned
Redundant constants module for the usize primitive type.
vec
A contiguous growable array type with heap-allocated contents, written Vec<T>.
intrinsicsExperimental
Compiler intrinsics.

Macros

assert
Asserts that a boolean expression is true at runtime.
assert_eq
Asserts that two expressions are equal to each other (using PartialEq).
assert_ne
Asserts that two expressions are not equal to each other (using PartialEq).
cfg
Evaluates boolean combinations of configuration flags at compile-time.
column
Expands to the column number at which it was invoked.
compile_error
Causes compilation to fail with the given error message when encountered.
concat
Concatenates literals into a static string slice.
debug_assert
Asserts that a boolean expression is true at runtime.
debug_assert_eq
Asserts that two expressions are equal to each other.
debug_assert_ne
Asserts that two expressions are not equal to each other.
env
Inspects an environment variable at compile time.
file
Expands to the file name in which it was invoked.
format
Creates a String using interpolation of runtime expressions.
format_args
Constructs parameters for the other string-formatting macros.
include
Parses a file as an expression or an item according to the context.
include_bytes
Includes a file as a reference to a byte array.
include_str
Includes a UTF-8 encoded file as a string.
line
Expands to the line number on which it was invoked.
matches
Returns whether the given expression matches the provided pattern.
module_path
Expands to a string that represents the current module path.
option_env
Optionally inspects an environment variable at compile time.
stringify
Stringifies its arguments.
unimplemented
Indicates unimplemented code by panicking with a message of “not implemented”.
unreachable
Indicates unreachable code.
vec
Creates a Vec containing the arguments.
write
Writes formatted data into a buffer.
writeln
Writes formatted data into a buffer, with a newline appended.

Traits

TryClone
Trait for fallible duplication of types that can be cloned.