Module alloc

Module alloc 

Allocation types for tipc-std.

Structs

Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.
AllocErrorExperimental
The AllocError error indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.