Sync

Trait Sync 

1.0.0 · Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

Source

impl Sync for core::ffi::c_str::Bytes<'_>

1.6.0 · Source

impl Sync for tipc_std::string::Drain<'_>

1.10.0 · Source

impl Sync for Location<'_>

1.0.0 · Source

impl Sync for TypeId

1.36.0 · Source

impl Sync for Waker

1.44.0 · Source

impl<'a> Sync for IoSlice<'a>

1.44.0 · Source

impl<'a> Sync for IoSliceMut<'a>

Source

impl<Dyn> Sync for DynMetadata<Dyn>
where Dyn: ?Sized,

1.0.0 · Source

impl<T, A> !Sync for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Sync for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Sync for tipc_std::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Sync for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

Source

impl<T, A> Sync for Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Sync for CursorMut<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for alloc::collections::vec_deque::drain::Drain<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for tipc_std::vec::Drain<'_, T, A>
where T: Sync, A: Sync + Allocator,

1.0.0 · Source

impl<T, A> Sync for tipc_std::vec::IntoIter<T, A>
where T: Sync, A: Allocator + Sync,

1.0.0 · Source

impl<T, A> Sync for LinkedList<T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Sync for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

1.4.0 · Source

impl<T, A> Sync for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

Source

impl<T: Send + Sync, F: Send> Sync for LazyLock<T, F>

Source

impl<T: Send> Sync for Mutex<T>

Source

impl<T: Send> Sync for OnceLock<T>

1.0.0 · Source

impl<T> !Sync for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for Cell<T>
where T: ?Sized,

1.25.0 · Source

impl<T> !Sync for NonNull<T>
where T: ?Sized,

NonNull pointers are not Sync because the data they reference may be aliased.

1.70.0 · Source

impl<T> !Sync for OnceCell<T>

1.0.0 · Source

impl<T> !Sync for RefCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for UnsafeCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Sync for Atomic<T>
where T: AtomicPrimitive,

1.31.0 · Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for tipc_std::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for tipc_std::slice::IterMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::IterMut<'_, T>
where T: Sync,

1.28.0 · Source

impl<T> Sync for NonZero<T>

1.31.0 · Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

Source

impl<T> Sync for SyncUnsafeCell<T>
where T: Sync + ?Sized,

Source

impl<T> Sync for SyncView<T>
where T: ?Sized,

Source

impl<T> Sync for ThinBox<T>
where T: Sync + ?Sized,

ThinBox<T> is Sync if T is Sync because the data is owned.

Source

impl<T> Sync for UnsafePinned<T>
where T: Sync + ?Sized,

Auto implementors



impl Sync for Abi



impl Sync for tipc_std::mem::Alignment



impl Sync for tipc_std::fmt::Alignment



impl Sync for AllocError



impl Sync for Array



impl Sync for Assume



impl Sync for AtomicOrdering



impl Sync for BasicBlock



impl Sync for Bool



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for CString



impl Sync for Char



impl Sync for CharCase



impl Sync for CharTryFromError



impl Sync for Const



impl Sync for CpuidResult



impl Sync for DebugAsHex



impl Sync for DecodeUtf16Error



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for Enum



impl Sync for Error



impl Sync for tipc_std::char::EscapeDebug



impl Sync for tipc_std::char::EscapeDefault



impl Sync for tipc_std::char::EscapeUnicode



impl Sync for FallibleCString



impl Sync for Field



impl Sync for FieldId



impl Sync for Float



impl Sync for FnPtr



impl Sync for FormattingOptions



impl Sync for FromUtf8Error



impl Sync for FromUtf16Error



impl Sync for Generic



impl Sync for GenericType



impl Sync for GetDisjointMutError



impl Sync for Infallible



impl Sync for Int



impl Sync for IntoChars



impl Sync for Lifetime



impl Sync for Locality



impl Sync for OneSidedRangeBound



impl Sync for Ordering



impl Sync for ParseBoolError



impl Sync for ParseCharError



impl Sync for PhantomPinned



impl Sync for Pointer



impl Sync for RangeFull



impl Sync for Reference



impl Sync for ReturnToArg



impl Sync for SearchStep



impl Sync for Sign



impl Sync for SimdAlign



impl Sync for SipHasher



impl Sync for Slice



impl Sync for Str



impl Sync for String



impl Sync for Struct



impl Sync for ToCasefold



impl Sync for ToLowercase



impl Sync for ToTitlecase



impl Sync for ToUppercase



impl Sync for Trait



impl Sync for TryFromCharError



impl Sync for TryFromSliceError



impl Sync for TryNewError



impl Sync for Tuple



impl Sync for Type



impl Sync for TypeKind



impl Sync for Union



impl Sync for UnwindActionArg



impl Sync for UnwindTerminateReason



impl Sync for Utf8Error



impl Sync for Variant



impl Sync for __m128



impl Sync for __m256



impl Sync for __m512



impl Sync for __m128bh



impl Sync for __m128d



impl Sync for __m128h



impl Sync for __m128i



impl Sync for __m256bh



impl Sync for __m256d



impl Sync for __m256h



impl Sync for __m256i



impl Sync for __m512bh



impl Sync for __m512d



impl Sync for __m512h



impl Sync for __m512i



impl Sync for __tile1024i



impl Sync for bf16



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, A> Sync for tipc_std::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Sync for tipc_std::option::IterMut<'a, A>
where A: Sync,



impl<'a, B> Sync for Cow<'a, B>
where <B as ToOwned>::Owned: Sync, B: Sync + ?Sized,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where F: Sync,



impl<'a, I, A> Sync for Splice<'a, I, A>
where I: Sync, <I as Iterator>::Item: Sync, A: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where I: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for tipc_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for tipc_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for tipc_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for tipc_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for tipc_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, T, A> Sync for PeekMut<'a, T, A>
where A: Sync, T: Sync,



impl<'a, T, F, A> Sync for ExtractIf<'a, T, F, A>
where F: Sync, A: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for tipc_std::slice::RSplit<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for tipc_std::slice::RSplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for tipc_std::slice::Split<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for tipc_std::slice::SplitInclusive<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for tipc_std::slice::SplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, T> Sync for Chunks<'a, T>
where T: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for tipc_std::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for tipc_std::result::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for MutexGuard<'a, T>
where T: Send,



impl<'a, T> Sync for RChunks<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for Windows<'a, T>
where T: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>



impl<'a> !Sync for Formatter<'a>



impl<'a> Sync for tipc_std::str::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for tipc_std::str::EscapeDebug<'a>



impl<'a> Sync for tipc_std::str::EscapeDefault<'a>



impl<'a> Sync for tipc_std::str::EscapeUnicode<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for Utf8Pattern<'a>



impl<'b, T> !Sync for Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<A, B> Sync for Chain<A, B>
where A: Sync, B: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<A> Sync for tipc_std::option::IntoIter<A>
where A: Sync,



impl<A> Sync for OptionFlatten<A>
where A: Sync,



impl<A> Sync for Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where A: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<F> Sync for tipc_std::iter::FromFn<F>
where F: Sync,



impl<F> Sync for tipc_std::fmt::FromFn<F>
where F: Sync,



impl<F> Sync for OnceWith<F>
where F: Sync,



impl<F> Sync for PollFn<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Sync, I: Sync, F: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for DecodeUtf16<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, I: Sync,



impl<I> Sync for Fuse<I>
where I: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for Take<I>
where I: Sync,



impl<Idx> Sync for Range<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeToInclusive<Idx>
where Idx: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<Ptr> Sync for Pin<Ptr>
where Ptr: Sync,



impl<T, A> Sync for Box<T, A>
where A: Sync, T: Sync + ?Sized,



impl<T, A> Sync for Vec<T, A>
where A: Sync, T: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl<T, F> Sync for DropGuard<T, F>
where T: Sync, F: Sync,



impl<T, F> Sync for Successors<T, F>
where F: Sync, T: Sync,



impl<T, const N: usize, A> Sync for BoxedArrayIntoIter<T, N, A>
where T: Sync, A: Sync,



impl<T, const N: usize> Sync for tipc_std::array::IntoIter<T, N>
where T: Sync,



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for Empty<T>



impl<T> Sync for tipc_std::result::IntoIter<T>
where T: Sync,



impl<T> Sync for ManuallyDrop<T>
where T: Sync + ?Sized,



impl<T> Sync for MaybeUninit<T>
where T: Sync,



impl<T> Sync for Once<T>
where T: Sync,



impl<T> Sync for Option<T>
where T: Sync,



impl<T> Sync for Pending<T>



impl<T> Sync for PhantomContravariant<T>
where T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: Sync + ?Sized,



impl<T> Sync for PhantomInvariant<T>
where T: ?Sized,



impl<T> Sync for PoisonError<T>
where T: Sync,



impl<T> Sync for Ready<T>
where T: Sync,



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for TraitImpl<T>
where T: ?Sized,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,