TIPC standard library type provider.
Provides the same API surface as trusty_std (TryClone, FallibleCString,
Mutex, etc.) in a no_std environment backed by core + alloc.
Both lk and x-kernel targets are no_std; the feature only selects
syscall numbering.
Modules
- alloc
- Allocation types for tipc-std.
- any
- Utilities for dynamic typing or type reflection.
- arch
- SIMD and vendor intrinsics module.
- array
- Utilities for the array primitive type.
- borrow
- A module for working with borrowed data.
- boxed
- The
Box<T>type for heap allocation. - cell
- Shareable mutable containers.
- char
- Utilities for the
charprimitive type. - clone
- The
Clonetrait for types that cannot be ‘implicitly copied’. - cmp
- Utilities for comparing and ordering values.
- convert
- Traits for conversions between types.
- default
- The
Defaulttrait for types with a default value. - ffi
- FFI types for tipc-std.
- fmt
- Utilities for formatting and printing
Strings. - future
- Asynchronous basic functionality.
- hash
- Generic hashing support.
- hint
- Hints to compiler that affects how code should be emitted or optimized.
- i8
Deprecation planned - Redundant constants module for the
i8primitive type. - i16
Deprecation planned - Redundant constants module for the
i16primitive type. - i32
Deprecation planned - Redundant constants module for the
i32primitive type. - i64
Deprecation planned - Redundant constants module for the
i64primitive type. - i128
Deprecation planned - Redundant constants module for the
i128primitive type. - isize
Deprecation planned - Redundant constants module for the
isizeprimitive type. - iter
- Composable external iteration.
- marker
- Primitive traits and types representing basic properties of types.
- mem
- Basic functions for dealing with memory, values, and types.
- ops
- Overloadable operators.
- option
- Optional values.
- pin
- Types that pin data to a location in memory.
- primitive
- This module reexports the primitive types to allow usage that is not possibly shadowed by other declared types.
- ptr
- Manually manage memory through raw pointers.
- rc
- Single-threaded reference-counting pointers. ‘Rc’ stands for ‘Reference Counted’.
- result
- Error handling with the
Resulttype. - slice
- Utilities for the slice primitive type.
- str
- Utilities for the
strprimitive type. - string
- A UTF-8–encoded, growable string.
- sync
- Synchronization primitives for tipc-std.
- u8
Deprecation planned - Redundant constants module for the
u8primitive type. - u16
Deprecation planned - Redundant constants module for the
u16primitive type. - u32
Deprecation planned - Redundant constants module for the
u32primitive type. - u64
Deprecation planned - Redundant constants module for the
u64primitive type. - u128
Deprecation planned - Redundant constants module for the
u128primitive type. - usize
Deprecation planned - Redundant constants module for the
usizeprimitive type. - vec
- A contiguous growable array type with heap-allocated contents, written
Vec<T>. - intrinsics
Experimental - Compiler intrinsics.
Macros
- assert
- Asserts that a boolean expression is
trueat runtime. - assert_
eq - Asserts that two expressions are equal to each other (using
PartialEq). - assert_
ne - Asserts that two expressions are not equal to each other (using
PartialEq). - cfg
- Evaluates boolean combinations of configuration flags at compile-time.
- column
- Expands to the column number at which it was invoked.
- compile_
error - Causes compilation to fail with the given error message when encountered.
- concat
- Concatenates literals into a static string slice.
- debug_
assert - Asserts that a boolean expression is
trueat runtime. - debug_
assert_ eq - Asserts that two expressions are equal to each other.
- debug_
assert_ ne - Asserts that two expressions are not equal to each other.
- env
- Inspects an environment variable at compile time.
- file
- Expands to the file name in which it was invoked.
- format
- Creates a
Stringusing interpolation of runtime expressions. - format_
args - Constructs parameters for the other string-formatting macros.
- include
- Parses a file as an expression or an item according to the context.
- include_
bytes - Includes a file as a reference to a byte array.
- include_
str - Includes a UTF-8 encoded file as a string.
- line
- Expands to the line number on which it was invoked.
- matches
- Returns whether the given expression matches the provided pattern.
- module_
path - Expands to a string that represents the current module path.
- option_
env - Optionally inspects an environment variable at compile time.
- stringify
- Stringifies its arguments.
- unimplemented
- Indicates unimplemented code by panicking with a message of “not implemented”.
- unreachable
- Indicates unreachable code.
- vec
- Creates a
Veccontaining the arguments. - write
- Writes formatted data into a buffer.
- writeln
- Writes formatted data into a buffer, with a newline appended.
Traits
- TryClone
- Trait for fallible duplication of types that can be cloned.