Allocation types for tipc-std.
Structs
- Vec
- A contiguous growable array type, written as
Vec<T>, short for ‘vector’. - Alloc
Error Experimental - The
AllocErrorerror indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.